package martcconf

import (
	"hoff.industries/marty/libmarty"
	"hoff.industries/marty/libmmp"
	"hoff.industries/marty/mendpoints"
)

type RTCEvent struct {
	Title string
	Oneshot bool

	DayMask uint8
	MonthMask uint16

	Messages []libmarty.MartyMessageHandle

	Skip bool
}

func RTC_2_heap(event RTCEvent) *RTCEvent{

	// note, does not dupe the messages

	var heapEvent = new(RTCEvent)

	heapEvent.Title = event.Title
	heapEvent.Oneshot = event.Oneshot
	heapEvent.DayMask = event.DayMask
	heapEvent.MonthMask = event.MonthMask
	heapEvent.Skip = event.Skip

	heapEvent.Messages = event.Messages

	return heapEvent
}

var MaRTCConf = map[string][]RTCEvent{

	"06:15:00": {
	{
		Title: "alarm_0_activate",
		Oneshot: false,

		DayMask: 0x1E,
		MonthMask: 0x0FFF,

		Messages: []libmarty.MartyMessageHandle{
			{

			Result: libmmp.ARGS_EMPTY,
			Execute: &libmmp.MMPacket{

			Type: libmmp.MMP_TYPE_SEND,
			Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
			Payloads: [][]byte{
				[]byte("-1"),
				[]byte("0"),
				[]byte("snowpoint"),
				[]byte("alarm"),
				{byte(mendpoints.ALARM_EPT_ACT)},
				[]byte("/home/mdhoff/bubbletea.flac"),
			},
			Bytes: nil,

			},

			Next: nil,
			},
		},

		Skip: false,
	},
	},

	"06:30:00": {
	{
		Title: "alarm_0.5_activate",
		Oneshot: false,

		DayMask: 0x1F,
		MonthMask: 0x0FFF,

		Messages: []libmarty.MartyMessageHandle{
			{

			Result: libmmp.ARGS_EMPTY,
			Execute: &libmmp.MMPacket{

			Type: libmmp.MMP_TYPE_SEND,
			Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
			Payloads: [][]byte{
				[]byte("-1"),
				[]byte("0"),
				[]byte("snowpoint"),
				[]byte("alarm"),
				{byte(mendpoints.ALARM_EPT_ACT)},
				[]byte("/home/mdhoff/bubbletea.flac"),
			},
			Bytes: nil,

			},

			Next: nil,
			},
		},

		Skip: false,
	},
	},

	"06:35:00": {
		{
			Title: "lamp_off_sunrise",
			Oneshot: false,

			DayMask: 0x1F,
			MonthMask: 0x0FFF,

			Messages: []libmarty.MartyMessageHandle{
				{

				Result: libmmp.ARGS_EMPTY,
				Execute: &libmmp.MMPacket{

				Type: libmmp.MMP_TYPE_SEND,
				Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
				Payloads: [][]byte{
					[]byte("-1"),
					[]byte("0"),
					[]byte("slateport"),
					[]byte("marqtt"),
					{byte(mendpoints.MARQTT_EPT_PUBLISH)},
					[]byte("marty/lamp_control/set"),
					[]byte("{\"scene_recall\": 0}"),
				},
				Bytes: nil,

				},

				Next: nil,
				},
			},

			Skip: false,
		},
	},

	"09:00:00": {
		{
			Title: "alarm_1_activate",
			Oneshot: false,

			DayMask: 0xFF,
			MonthMask: 0x0FFF,

			Messages: []libmarty.MartyMessageHandle{
				{

				Result: libmmp.ARGS_EMPTY,
				Execute: &libmmp.MMPacket{

				Type: libmmp.MMP_TYPE_SEND,
				Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
				Payloads: [][]byte{
					[]byte("-1"),
					[]byte("0"),
					[]byte("snowpoint"),
					[]byte("alarm"),
					{byte(mendpoints.ALARM_EPT_ACT)},
					[]byte("/home/mdhoff/seeyouagain.flac"),
				},
				Bytes: nil,

				},

				Next: nil,
				},
			},

		Skip: false,
		},
	},

	"09:15:00": {
		{
			Title: "lamp_scene_top",
			Oneshot: false,

			DayMask: 0xFF,
			MonthMask: 0x0FFF,

			Messages: []libmarty.MartyMessageHandle{
				{

					Result: libmmp.ARGS_EMPTY,
					Execute: &libmmp.MMPacket{

						Type: libmmp.MMP_TYPE_SEND,
						Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
						Payloads: [][]byte{
							[]byte("-1"),
							[]byte("0"),
							[]byte("slateport"),
							[]byte("marqtt"),
							{byte(mendpoints.MARQTT_EPT_PUBLISH)},
							[]byte("marty/lamp_control/set"),
							[]byte("{\"scene_recall\": 0}"),
						},
						Bytes: nil,

					},

					Next: nil,
				},
			},

			Skip: false,
		},
	},

	"16:25:00": {
		{
			Title: "lamp_scene_top",
			Oneshot: false,

			DayMask: 0xFF,
			MonthMask: 0x0FFF,

			Messages: []libmarty.MartyMessageHandle{
				{

					Result: libmmp.ARGS_EMPTY,
					Execute: &libmmp.MMPacket{

						Type: libmmp.MMP_TYPE_SEND,
						Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
						Payloads: [][]byte{
							[]byte("-1"),
							[]byte("0"),
							[]byte("slateport"),
							[]byte("marqtt"),
							{byte(mendpoints.MARQTT_EPT_PUBLISH)},
							[]byte("marty/lamp_control/set"),
							[]byte("{\"scene_recall\": 2}"),
						},
						Bytes: nil,

					},

					Next: nil,
				},
			},

			Skip: false,
		},
	},

	"17:45:00": {
		{
			Title: "lamp_scene_top",
			Oneshot: false,

			DayMask: 0xFF,
			MonthMask: 0x0FFF,

			Messages: []libmarty.MartyMessageHandle{
				{

					Result: libmmp.ARGS_EMPTY,
					Execute: &libmmp.MMPacket{

						Type: libmmp.MMP_TYPE_SEND,
						Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
						Payloads: [][]byte{
							[]byte("-1"),
							[]byte("0"),
							[]byte("slateport"),
							[]byte("marqtt"),
							{byte(mendpoints.MARQTT_EPT_PUBLISH)},
							[]byte("marty/lamp_control/set"),
							[]byte("{\"scene_recall\": 3}"),
						},
						Bytes: nil,

					},

					Next: nil,
				},
			},

			Skip: false,
		},
	},

	"18:30:00": {
		{
			Title: "lamp_scene_top",
			Oneshot: false,

			DayMask: 0xFF,
			MonthMask: 0x0FFF,

			Messages: []libmarty.MartyMessageHandle{
				{

					Result: libmmp.ARGS_EMPTY,
					Execute: &libmmp.MMPacket{

						Type: libmmp.MMP_TYPE_SEND,
						Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
						Payloads: [][]byte{
							[]byte("-1"),
							[]byte("0"),
							[]byte("slateport"),
							[]byte("marqtt"),
							{byte(mendpoints.MARQTT_EPT_PUBLISH)},
							[]byte("marty/lamp_control/set"),
							[]byte("{\"scene_recall\": 1}"),
						},
						Bytes: nil,

					},

					Next: nil,
				},
			},

			Skip: false,
		},
	},

	"21:00:00": {
		{
			Title: "lamp_scene_top",
			Oneshot: false,

			DayMask: 0xFF,
			MonthMask: 0x0FFF,

			Messages: []libmarty.MartyMessageHandle{
				{

					Result: libmmp.ARGS_EMPTY,
					Execute: &libmmp.MMPacket{

						Type: libmmp.MMP_TYPE_SEND,
						Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
						Payloads: [][]byte{
							[]byte("-1"),
							[]byte("0"),
							[]byte("slateport"),
							[]byte("marqtt"),
							{byte(mendpoints.MARQTT_EPT_PUBLISH)},
							[]byte("marty/lamp_control/set"),
							[]byte("{\"scene_recall\": 4}"),
						},
						Bytes: nil,

					},

					Next: nil,
				},
			},

			Skip: false,
		},
	},

	"23:00:00": {
		{
			Title: "lamp_scene_top",
			Oneshot: false,

			DayMask: 0xFF,
			MonthMask: 0x0FFF,

			Messages: []libmarty.MartyMessageHandle{
				{

					Result: libmmp.ARGS_EMPTY,
					Execute: &libmmp.MMPacket{

						Type: libmmp.MMP_TYPE_SEND,
						Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
						Payloads: [][]byte{
							[]byte("-1"),
							[]byte("0"),
							[]byte("slateport"),
							[]byte("marqtt"),
							{byte(mendpoints.MARQTT_EPT_PUBLISH)},
							[]byte("marty/lamp_control/set"),
							[]byte("{\"scene_recall\": 16}"),
						},
						Bytes: nil,

					},

					Next: nil,
				},

				{

					Result: libmmp.ARGS_EMPTY,
					Execute: &libmmp.MMPacket{

						Type: libmmp.MMP_TYPE_SEND,
						Argument: libmmp.MMPArgs[libmmp.MMP_TYPE_SEND]["DIRECT"],
						Payloads: [][]byte{
							[]byte("-1"),
							[]byte("0"),
							[]byte("sunyshore"),
							[]byte("radio"),
							{byte(mendpoints.RADIO_EPT_NORMAL)},
							[]byte("Time for bed, my friend."),
						},
						Bytes: nil,

					},

					Next: nil,
				},
			},

			Skip: false,
		},
	},
}
